@@ -1,11 +1,10 @@
 package Pod::Elemental::Node;
 # ABSTRACT: a thing with Pod::Elemental::Nodes as children
-$Pod::Elemental::Node::VERSION = '0.103002';
+$Pod::Elemental::Node::VERSION = '0.103003';
 use Moose::Role;
 
 use namespace::autoclean;
 
-use Moose::Autobox;
 use MooseX::Types;
 use MooseX::Types::Moose qw(ArrayRef);
 use Moose::Util::TypeConstraints qw(class_type);
@@ -39,7 +38,7 @@ around as_debug_string => sub {
 
   my $str = $self->$orig;
 
-  my @children = map { $_->as_debug_string } $self->children->flatten;
+  my @children = map { $_->as_debug_string } @{ $self->children };
   s/^/  /sgm for @children;
 
   $str = join "\n", $str, @children;
@@ -61,7 +60,7 @@ Pod::Elemental::Node - a thing with Pod::Elemental::Nodes as children
 
 =head1 VERSION
 
-version 0.103002
+version 0.103003
 
 =head1 OVERVIEW
 
